==> google-cloud-talent-2.3.0.tar.gz: google-cloud-talent-2.3.0/google/cloud/talent_v4beta1/types/__init__.py <==
# -*- coding: utf-8 -*-
# Copyright 2020 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from .application import Application
from .application_service import (
    CreateApplicationRequest,
    DeleteApplicationRequest,
    GetApplicationRequest,
    ListApplicationsRequest,
    ListApplicationsResponse,
    UpdateApplicationRequest,
)
from .common import (
    BatchOperationMetadata,
    Certification,
    CompensationInfo,
    CustomAttribute,
    DeviceInfo,
    Interview,
    Location,
    Rating,
    RequestMetadata,
    ResponseMetadata,
    Skill,
    SpellingCorrection,
    TimestampRange,
    AvailabilitySignalType,
    CommuteMethod,
    CompanySize,
    ContactInfoUsage,
    DegreeType,
    EmploymentType,
    HtmlSanitization,
    JobBenefit,
    JobCategory,
    JobLevel,
    Outcome,
    PostingRegion,
    SkillProficiencyLevel,
    Visibility,
)
from .company import Company
from .company_service import (
    CreateCompanyRequest,
    DeleteCompanyRequest,
    GetCompanyRequest,
    ListCompaniesRequest,
    ListCompaniesResponse,
    UpdateCompanyRequest,
)
from .completion_service import (
    CompleteQueryRequest,
    CompleteQueryResponse,
)
from .event import (
    ClientEvent,
    JobEvent,
    ProfileEvent,
)
from .event_service import CreateClientEventRequest
from .filters import (
    ApplicationDateFilter,
    ApplicationJobFilter,
    ApplicationOutcomeNotesFilter,
    AvailabilityFilter,
    CandidateAvailabilityFilter,
    CommuteFilter,
    CompensationFilter,
    EducationFilter,
    EmployerFilter,
    JobQuery,
    JobTitleFilter,
    LocationFilter,
    PersonNameFilter,
    ProfileQuery,
    SkillFilter,
    TimeFilter,
    WorkExperienceFilter,
)
from .histogram import (
    HistogramQuery,
    HistogramQueryResult,
)
from .job import Job
from .job_service import (
    BatchCreateJobsRequest,
    BatchDeleteJobsRequest,
    BatchUpdateJobsRequest,
    CreateJobRequest,
    DeleteJobRequest,
    GetJobRequest,
    JobOperationResult,
    ListJobsRequest,
    ListJobsResponse,
    SearchJobsRequest,
    SearchJobsResponse,
    UpdateJobRequest,
    JobView,
)
from .profile import (
    Activity,
    AdditionalContactInfo,
    Address,
    AvailabilitySignal,
    Degree,
    EducationRecord,
    Email,
    EmploymentRecord,
    Patent,
    PersonalUri,
    PersonName,
    Phone,
    Profile,
    Publication,
    Resume,
)
from .profile_service import (
    CreateProfileRequest,
    DeleteProfileRequest,
    GetProfileRequest,
    ListProfilesRequest,
    ListProfilesResponse,
    SearchProfilesRequest,
    SearchProfilesResponse,
    SummarizedProfile,
    UpdateProfileRequest,
)
from .tenant import Tenant
from .tenant_service import (
    CreateTenantRequest,
    DeleteTenantRequest,
    GetTenantRequest,
    ListTenantsRequest,
    ListTenantsResponse,
    UpdateTenantRequest,
)

__all__ = (
    "Application",
    "CreateApplicationRequest",
    "DeleteApplicationRequest",
    "GetApplicationRequest",
    "ListApplicationsRequest",
    "ListApplicationsResponse",
    "UpdateApplicationRequest",
    "BatchOperationMetadata",
    "Certification",
    "CompensationInfo",
    "CustomAttribute",
    "DeviceInfo",
    "Interview",
    "Location",
    "Rating",
    "RequestMetadata",
    "ResponseMetadata",
    "Skill",
    "SpellingCorrection",
    "TimestampRange",
    "AvailabilitySignalType",
    "CommuteMethod",
    "CompanySize",
    "ContactInfoUsage",
    "DegreeType",
    "EmploymentType",
    "HtmlSanitization",
    "JobBenefit",
    "JobCategory",
    "JobLevel",
    "Outcome",
    "PostingRegion",
    "SkillProficiencyLevel",
    "Visibility",
    "Company",
    "CreateCompanyRequest",
    "DeleteCompanyRequest",
    "GetCompanyRequest",
    "ListCompaniesRequest",
    "ListCompaniesResponse",
    "UpdateCompanyRequest",
    "CompleteQueryRequest",
    "CompleteQueryResponse",
    "ClientEvent",
    "JobEvent",
    "ProfileEvent",
    "CreateClientEventRequest",
    "ApplicationDateFilter",
    "ApplicationJobFilter",
    "ApplicationOutcomeNotesFilter",
    "AvailabilityFilter",
    "CandidateAvailabilityFilter",
    "CommuteFilter",
    "CompensationFilter",
    "EducationFilter",
    "EmployerFilter",
    "JobQuery",
    "JobTitleFilter",
    "LocationFilter",
    "PersonNameFilter",
    "ProfileQuery",
    "SkillFilter",
    "TimeFilter",
    "WorkExperienceFilter",
    "HistogramQuery",
    "HistogramQueryResult",
    "Job",
    "BatchCreateJobsRequest",
    "BatchDeleteJobsRequest",
    "BatchUpdateJobsRequest",
    "CreateJobRequest",
    "DeleteJobRequest",
    "GetJobRequest",
    "JobOperationResult",
    "ListJobsRequest",
    "ListJobsResponse",
    "SearchJobsRequest",
    "SearchJobsResponse",
    "UpdateJobRequest",
    "JobView",
    "Activity",
    "AdditionalContactInfo",
    "Address",
    "AvailabilitySignal",
    "Degree",
    "EducationRecord",
    "Email",
    "EmploymentRecord",
    "Patent",
    "PersonalUri",
    "PersonName",
    "Phone",
    "Profile",
    "Publication",
    "Resume",
    "CreateProfileRequest",
    "DeleteProfileRequest",
    "GetProfileRequest",
    "ListProfilesRequest",
    "ListProfilesResponse",
    "SearchProfilesRequest",
    "SearchProfilesResponse",
    "SummarizedProfile",
    "UpdateProfileRequest",
    "Tenant",
    "CreateTenantRequest",
    "DeleteTenantRequest",
    "GetTenantRequest",
    "ListTenantsRequest",
    "ListTenantsResponse",
    "UpdateTenantRequest",
)

==> google-cloud-talent-2.6.0.tar.gz: google-cloud-talent-2.6.0/google/cloud/talent_v4beta1/types/__init__.py <==
# -*- coding: utf-8 -*-
# Copyright 2022 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from .application import Application
from .application_service import (
    CreateApplicationRequest,
    DeleteApplicationRequest,
    GetApplicationRequest,
    ListApplicationsRequest,
    ListApplicationsResponse,
    UpdateApplicationRequest,
)
from .common import (
    AvailabilitySignalType,
    BatchOperationMetadata,
    Certification,
    CommuteMethod,
    CompanySize,
    CompensationInfo,
    ContactInfoUsage,
    CustomAttribute,
    DegreeType,
    DeviceInfo,
    EmploymentType,
    HtmlSanitization,
    Interview,
    JobBenefit,
    JobCategory,
    JobLevel,
    Location,
    Outcome,
    PostingRegion,
    Rating,
    RequestMetadata,
    ResponseMetadata,
    Skill,
    SkillProficiencyLevel,
    SpellingCorrection,
    TimestampRange,
    Visibility,
)
from .company import Company
from .company_service import (
    CreateCompanyRequest,
    DeleteCompanyRequest,
    GetCompanyRequest,
    ListCompaniesRequest,
    ListCompaniesResponse,
    UpdateCompanyRequest,
)
from .completion_service import CompleteQueryRequest, CompleteQueryResponse
from .event import ClientEvent, JobEvent, ProfileEvent
from .event_service import CreateClientEventRequest
from .filters import (
    ApplicationDateFilter,
    ApplicationJobFilter,
    ApplicationOutcomeNotesFilter,
    AvailabilityFilter,
    CandidateAvailabilityFilter,
    CommuteFilter,
    CompensationFilter,
    EducationFilter,
    EmployerFilter,
    JobQuery,
    JobTitleFilter,
    LocationFilter,
    PersonNameFilter,
    ProfileQuery,
    SkillFilter,
    TimeFilter,
    WorkExperienceFilter,
)
from .histogram import HistogramQuery, HistogramQueryResult
from .job import Job
from .job_service import (
    BatchCreateJobsRequest,
    BatchDeleteJobsRequest,
    BatchUpdateJobsRequest,
    CreateJobRequest,
    DeleteJobRequest,
    GetJobRequest,
    JobOperationResult,
    JobView,
    ListJobsRequest,
    ListJobsResponse,
    SearchJobsRequest,
    SearchJobsResponse,
    UpdateJobRequest,
)
from .profile import (
    Activity,
    AdditionalContactInfo,
    Address,
    AvailabilitySignal,
    Degree,
    EducationRecord,
    Email,
    EmploymentRecord,
    Patent,
    PersonalUri,
    PersonName,
    Phone,
    Profile,
    Publication,
    Resume,
)
from .profile_service import (
    CreateProfileRequest,
    DeleteProfileRequest,
    GetProfileRequest,
    ListProfilesRequest,
    ListProfilesResponse,
    SearchProfilesRequest,
    SearchProfilesResponse,
    SummarizedProfile,
    UpdateProfileRequest,
)
from .tenant import Tenant
from .tenant_service import (
    CreateTenantRequest,
    DeleteTenantRequest,
    GetTenantRequest,
    ListTenantsRequest,
    ListTenantsResponse,
    UpdateTenantRequest,
)

__all__ = (
    "Application",
    "CreateApplicationRequest",
    "DeleteApplicationRequest",
    "GetApplicationRequest",
    "ListApplicationsRequest",
    "ListApplicationsResponse",
    "UpdateApplicationRequest",
    "BatchOperationMetadata",
    "Certification",
    "CompensationInfo",
    "CustomAttribute",
    "DeviceInfo",
    "Interview",
    "Location",
    "Rating",
    "RequestMetadata",
    "ResponseMetadata",
    "Skill",
    "SpellingCorrection",
    "TimestampRange",
    "AvailabilitySignalType",
    "CommuteMethod",
    "CompanySize",
    "ContactInfoUsage",
    "DegreeType",
    "EmploymentType",
    "HtmlSanitization",
    "JobBenefit",
    "JobCategory",
    "JobLevel",
    "Outcome",
    "PostingRegion",
    "SkillProficiencyLevel",
    "Visibility",
    "Company",
    "CreateCompanyRequest",
    "DeleteCompanyRequest",
    "GetCompanyRequest",
    "ListCompaniesRequest",
    "ListCompaniesResponse",
    "UpdateCompanyRequest",
    "CompleteQueryRequest",
    "CompleteQueryResponse",
    "ClientEvent",
    "JobEvent",
    "ProfileEvent",
    "CreateClientEventRequest",
    "ApplicationDateFilter",
    "ApplicationJobFilter",
    "ApplicationOutcomeNotesFilter",
    "AvailabilityFilter",
    "CandidateAvailabilityFilter",
    "CommuteFilter",
    "CompensationFilter",
    "EducationFilter",
    "EmployerFilter",
    "JobQuery",
    "JobTitleFilter",
    "LocationFilter",
    "PersonNameFilter",
    "ProfileQuery",
    "SkillFilter",
    "TimeFilter",
    "WorkExperienceFilter",
    "HistogramQuery",
    "HistogramQueryResult",
    "Job",
    "BatchCreateJobsRequest",
    "BatchDeleteJobsRequest",
    "BatchUpdateJobsRequest",
    "CreateJobRequest",
    "DeleteJobRequest",
    "GetJobRequest",
    "JobOperationResult",
    "ListJobsRequest",
    "ListJobsResponse",
    "SearchJobsRequest",
    "SearchJobsResponse",
    "UpdateJobRequest",
    "JobView",
    "Activity",
    "AdditionalContactInfo",
    "Address",
    "AvailabilitySignal",
    "Degree",
    "EducationRecord",
    "Email",
    "EmploymentRecord",
    "Patent",
    "PersonalUri",
    "PersonName",
    "Phone",
    "Profile",
    "Publication",
    "Resume",
    "CreateProfileRequest",
    "DeleteProfileRequest",
    "GetProfileRequest",
    "ListProfilesRequest",
    "ListProfilesResponse",
    "SearchProfilesRequest",
    "SearchProfilesResponse",
    "SummarizedProfile",
    "UpdateProfileRequest",
    "Tenant",
    "CreateTenantRequest",
    "DeleteTenantRequest",
    "GetTenantRequest",
    "ListTenantsRequest",
    "ListTenantsResponse",
    "UpdateTenantRequest",
)
